==> live555_2020.12.08.orig.tar.gz: live/groupsock/GroupEId.cpp <==
/**********
This library is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version. (See <http://www.gnu.org/copyleft/lesser.html>.)

This library is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
more details.

You should have received a copy of the GNU Lesser General Public License
along with this library; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
**********/
// Copyright (c) 1996-2021, Live Networks, Inc.  All rights reserved
// "Group Endpoint Id"
// Implementation

#include "GroupEId.hh"


GroupEId::GroupEId(struct sockaddr_storage const& groupAddr,
		   portNumBits portNum, u_int8_t ttl) {
  init(groupAddr, AddressPortLookupTable::dummyAddress(), portNum, ttl);
}

GroupEId::GroupEId(struct sockaddr_storage const& groupAddr,
		   struct sockaddr_storage const& sourceFilterAddr,
		   portNumBits portNum) {
  init(groupAddr, sourceFilterAddr, portNum, 255);
}

GroupEId::GroupEId() {
  init(AddressPortLookupTable::dummyAddress(), AddressPortLookupTable::dummyAddress(),
       0, 255);
}

Boolean GroupEId::isSSM() const {
  // We're a SSM group if "fSourceFilterAddress" is not a dummy address:
  return !(fSourceFilterAddress.ss_family == AF_INET &&
	   ((sockaddr_in&)fSourceFilterAddress).sin_addr.s_addr == (~0));
}

portNumBits GroupEId::portNum() const {
  return ((struct sockaddr_in const&)fGroupAddress).sin_port; // same position for IPv6
}

void GroupEId::init(struct sockaddr_storage const& groupAddr,
		    struct sockaddr_storage const& sourceFilterAddr,
		    portNumBits portNum,
		    u_int8_t ttl) {
  fGroupAddress = groupAddr;
  ((sockaddr_in&)fGroupAddress).sin_port = portNum; // same position for IPv6
  
  fSourceFilterAddress = sourceFilterAddr;

  fTTL = ttl;
}

==> live555_2020.12.12.orig.tar.gz: live/groupsock/GroupEId.cpp <==
/**********
This library is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version. (See <http://www.gnu.org/copyleft/lesser.html>.)

This library is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
more details.

You should have received a copy of the GNU Lesser General Public License
along with this library; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
**********/
// Copyright (c) 1996-2021, Live Networks, Inc.  All rights reserved
// "Group Endpoint Id"
// Implementation

#include "GroupEId.hh"


GroupEId::GroupEId(struct sockaddr_storage const& groupAddr,
		   portNumBits portNum, u_int8_t ttl) {
  init(groupAddr, nullAddress(), portNum, ttl);
}

GroupEId::GroupEId(struct sockaddr_storage const& groupAddr,
		   struct sockaddr_storage const& sourceFilterAddr,
		   portNumBits portNum) {
  init(groupAddr, sourceFilterAddr, portNum, 255);
}

GroupEId::GroupEId() {
  init(nullAddress(), nullAddress(), 0, 255);
}

Boolean GroupEId::isSSM() const {
  // We're a SSM group if "fSourceFilterAddress" is not a 'null' address:
  return !addressIsNull(fSourceFilterAddress);
}

portNumBits GroupEId::portNum() const { return ::portNum(fGroupAddress); }

void GroupEId::init(struct sockaddr_storage const& groupAddr,
		    struct sockaddr_storage const& sourceFilterAddr,
		    portNumBits portNum,
		    u_int8_t ttl) {
  fGroupAddress = groupAddr;
  ((sockaddr_in&)fGroupAddress).sin_port = portNum; // same position for IPv6
  
  fSourceFilterAddress = sourceFilterAddr;

  fTTL = ttl;
}
